autoBOTLib — autoBOTLib documentation

# autoBOTLib

- autoBOTLib package
  - Submodules
  - autoBOTLib.features_concepts module
  - autoBOTLib.features_contextual module
  - autoBOTLib.features_document_graph module
  - autoBOTLib.features_keyword module
  - autoBOTLib.features_sentence_embeddings module
  - autoBOTLib.features_token_relations module
  - autoBOTLib.features_topic module
  - autoBOTLib.misc_helpers module
  - autoBOTLib.misc_keyword_detection module
  - autoBOTLib.optimization_engine module
  - autoBOTLib.optimization_feature_constructors module
  - autoBOTLib.optimization_metrics module
  - autoBOTLib.optimization_random module
  - autoBOTLib.optimization_utils module
  - Module contents